@@ -1,6 +1,6 @@
 extern crate meter_proxy;
 
-use meter_proxy::proxy::MeterProxy;
+use meter_proxy::proxy::sync::SyncMeterProxy;
 use std::thread;
 use std::time::Duration;
 
